@@ -1,7 +1,7 @@
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 
-from spotify_uri.parse import parse
+from spotify_uri.parse import parse as _parse
 from spotify_uri.search import Search as _Search
 from spotify_uri.local import Local as _Local
 from spotify_uri.playlist import Playlist as _Playlist
@@ -12,25 +12,25 @@ from spotify_uri.user import User as _User
 from spotify_uri.spotify import SpotifyUri
 
 
-def parseSpotifyUri(uri: str):
-    return parse(uri)
+def parse(uri: str):
+    return _parse(uri)
 
 
 def formatURI(_input: str) -> str:
-    _uri = parse(_input)
+    _uri: SpotifyUri = parse(_input) if bool(type(_input) == str) else _input
     return _uri.toURI()
 
 
 def formatEmbedURL(_input: str) -> str:
-    _uri = parse(_input)
+    _uri: SpotifyUri = parse(_input) if bool(type(_input) == str) else _input
     return _uri.toEmbedURL()
 
 
-def formatOpenURL(_input: str):
-    _uri = parse(_input)
+def formatOpenURL(_input: str) -> str:
+    _uri: SpotifyUri = parse(_input) if bool(type(_input) == str) else _input
     return _uri.toOpenURL()
 
 
-def formatPlayURL(_input: str):
-    _uri = parse(_input)
+def formatPlayURL(_input: str) -> str:
+    _uri: SpotifyUri = parse(_input) if bool(type(_input) == str) else _input
     return _uri.toPlayURL()
