@@ -1,13 +1,23 @@
+from typing import Any
 from spotify_uri.spotify import SpotifyUri
 from spotify_uri.util import encode
 
 
 class Playlist(SpotifyUri):
-    def __init__(self, uri: str, _id: str = None, user: str = None):
+    def __init__(self, uri: str, _id: str = None, user: str = None) -> None:
+        self.type = "playlist"
         self.id = _id
         self.user = user
         super(Playlist, self).__init__(uri)
 
+    @staticmethod
+    def is_(v: Any) -> bool:
+        x = v is Playlist
+        if x:
+            return v.type == "playlist"
+        else:
+            return False
+
     def toURI(self) -> str:
         if self.user:
             if self.id == "starred":
