@@ -1,3 +1,4 @@
+from typing import Any
 from spotify_uri.spotify import SpotifyUri
 from spotify_uri.util import encode
 
@@ -8,6 +9,14 @@ class User(SpotifyUri):
         self.user = user
         super(User, self).__init__(uri)
 
+    @staticmethod
+    def is_(v: Any) -> bool:
+        x = v is User
+        if x:
+            return v.type == "user"
+        else:
+            return False
+
     def toURI(self) -> str:
         return f"spotify:{self.type}:{encode(self.user)}"
 
